MultimodalModel
===============

.. currentmodule:: pykeen.models

.. autoclass:: MultimodalModel
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MultimodalModel.score_h
      ~MultimodalModel.score_hrt
      ~MultimodalModel.score_r
      ~MultimodalModel.score_t

   .. rubric:: Methods Documentation

   .. automethod:: score_h
   .. automethod:: score_hrt
   .. automethod:: score_r
   .. automethod:: score_t
